import argparse
import logging
from logging import Logger
from agents.coding_agent import FallbackOnLimitAgent, LoggingAgent, WaitingOnLimitAgent
from agents.providers.glm import GLMAgent
from agents.providers.sonnet import ClaudeAgent


def parse_init_args() -> argparse.Namespace:
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--instructions_path", required=True, help="Path to system instructions file"
    )
    parser.add_argument(
        "--files",
        required=False,
        help="Extra file pathes for agent to read before starting work",
        nargs="+",
        default=[],
    )
    return parser.parse_args()


if __name__ == "__main__":
    sonnet_agent = ClaudeAgent()
    glm_agent = GLMAgent()
    fallback_agent = FallbackOnLimitAgent(sonnet_agent, glm_agent)
    waiting_agent = WaitingOnLimitAgent(fallback_agent, wait_hours=2)
    # Configure a logger that writes to ./full_agents_log.txt
    logger: Logger = logging.getLogger("agents.full")
    logger.setLevel(logging.INFO)
    if not logger.handlers:
        file_handler = logging.FileHandler("./full_agents_log.txt", encoding="utf-8")
        file_handler.setLevel(logging.INFO)
        formatter = logging.Formatter("%(asctime)s %(levelname)s %(message)s")
        file_handler.setFormatter(formatter)
        logger.addHandler(file_handler)
    logger.propagate = False
    logging_agent = LoggingAgent(waiting_agent, logger)

    args = parse_init_args()
    logging_agent.run(
        prompt=f"You instructions are stored in file @{args.instructions_path}. Read it fully and strictly follow them!\n\n",
        files_to_include=args.files,
    )



import argparse
import logging
from logging import Logger
from agents.coding_agent import FallbackOnLimitAgent, LoggingAgent, WaitingOnLimitAgent
from agents.providers.glm import GLMAgent
from agents.providers.sonnet import ClaudeAgent


def parse_init_args() -> argparse.Namespace:
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--session_id",
        required=True,
        help="Session ID (valid UUID), to get it run init of the agent first.",
    )
    parser.add_argument(
        "--message", required=True, help="Message to send to the agent."
    )
    return parser.parse_args()


if __name__ == "__main__":
    sonnet_agent = ClaudeAgent()
    glm_agent = GLMAgent()
    fallback_agent = FallbackOnLimitAgent(sonnet_agent, glm_agent)
    waiting_agent = WaitingOnLimitAgent(fallback_agent, wait_hours=2)
    # Configure a logger that writes to ./full_agents_log.txt
    logger: Logger = logging.getLogger("agents.full")
    logger.setLevel(logging.INFO)
    if not logger.handlers:
        file_handler = logging.FileHandler("./full_agents_log.txt", encoding="utf-8")
        file_handler.setLevel(logging.INFO)
        formatter = logging.Formatter("%(asctime)s %(levelname)s %(message)s")
        file_handler.setFormatter(formatter)
        logger.addHandler(file_handler)
    logger.propagate = False
    logging_agent = LoggingAgent(waiting_agent, logger)

    args = parse_init_args()
    logging_agent.resume(prompt=args.message, session_id=args.session_id)



import os
import sys
from agents.coding_agent import LimitExceededError
from agents.providers.sonnet import ClaudeAgent
from agents.send_email import send_email
from agents.utils import parse_common_args, build_prompt


class GLMAgent(ClaudeAgent):
    def __init__(
        self,
        model: str = "sonnet",
        files_to_always_include: list[str] | None = None,
        working_dir: str = "./",
    ):
        super().__init__(model, files_to_always_include, working_dir)
        self.glm_cmd = [
            "ANTHROPIC_BASE_URL=https://open.bigmodel.cn/api/anthropic",
            f"ANTHROPIC_AUTH_TOKEN={os.environ['GLM_AUTH_TOKEN']}",
        ]

    def _build_cmd(self, prompt: str, files_to_include: list[str]) -> list[str]:
        claude_cmd = super()._build_cmd(prompt)
        return self.glm_cmd + claude_cmd

    def _build_resume_cmd(self, prompt: str) -> list[str]:
        claude_cmd = super()._build_resume_cmd(prompt)
        return self.glm_cmd + claude_cmd


def main():
    args = parse_common_args()
    prompt = build_prompt(args.instructions, args.message)
    agent = GLMAgent()
    try:
        result = agent.run(prompt, files_to_include=args.files)
    except LimitExceededError:
        send_email("glm limits exceeded")
        sys.stdout.write("glm is not available right now")
        sys.exit(1)
    sys.stdout.write(result)
    sys.exit(0)


if __name__ == "__main__":
    main()



import sys
import uuid
from agents.coding_agent import CLIAgent, LimitExceededError, NothingToContinueError
from agents.send_email import send_email
from agents.utils import get_file_tags_suffix, parse_common_args, build_prompt

# todo support re-auth

LIMITS_EXCEEDED_ERROR = "5-hour limit reached"


class ClaudeAgent(CLIAgent):
    def __init__(
        self,
        model: str = "sonnet",
        files_to_always_include: list[str] | None = None,
        working_dir: str = "./",
    ):
        super().__init__(files_to_always_include, working_dir)
        self.model = model
        self.resumable = False
        self._new_session_id: str | None = None

    def _build_cmd(self, prompt: str, files_to_include: list[str]) -> list[str]:
        prompt_suffix = get_file_tags_suffix(
            self.files_to_always_include + (files_to_include or []), self.working_dir
        )
        full_prompt = prompt + prompt_suffix

        self._new_session_id = str(uuid.uuid4())

        cmd = [
            "claude",
            "--model",
            self.model,
            "--dangerously-skip-permissions",
            "--print",
            f"--session_id {self._new_session_id}",
            full_prompt,
        ]
        return cmd

    def run(self, prompt: str, files_to_include: list[str] | None = None) -> str:
        self.resumable = False
        content = super().run(prompt, files_to_include)
        if LIMITS_EXCEEDED_ERROR in content:
            raise LimitExceededError
        self.resumable = True

        content += f"\n\nSession id of this conversation: {self._new_session_id}\nUse it to contunie this conversation."

        return content

    def _build_resume_cmd(
        self, prompt: str, session_id: str | None = None
    ) -> list[str]:
        cmd = [
            "claude",
            "--model",
            self.model,
            "--dangerously-skip-permissions",
            "--print",
        ]

        if session_id:
            cmd.appned(f"--resume {session_id}")
        else:
            cmd.append("--continue")

        cmd.append(prompt)

        return cmd

    def resume(self, prompt: str | None, session_id: str | None = None) -> str:
        if not self.resumable:
            raise NothingToContinueError
        content = super().resume(prompt, session_id)
        if LIMITS_EXCEEDED_ERROR in content:
            raise LimitExceededError
        return content


def main():
    args = parse_common_args()
    prompt = build_prompt(args.instructions, args.message)
    agent = ClaudeAgent()
    try:
        result = agent.run(prompt, files_to_include=args.files)
    except LimitExceededError:
        send_email("claude limits exceeded")
        sys.stdout.write("claude is not available right now")
        sys.exit(1)
    sys.stdout.write(result)
    sys.exit(0)


if __name__ == "__main__":
    main()
